@@ -6,19 +6,19 @@ from .filterset import FilterSet
 
 # We make the `rest_framework` module available without an additional import.
 #   If DRF is not installed, no-op.
-if pkgutil.find_loader('rest_framework') is not None:
+if pkgutil.find_loader("rest_framework") is not None:
     from . import rest_framework
 del pkgutil
 
-__version__ = '21.1'
+__version__ = "23.2"
 
 
 def parse_version(version):
-    '''
+    """
     '0.1.2.dev1' -> (0, 1, 2, 'dev1')
     '0.1.2' -> (0, 1, 2)
-    '''
-    v = version.split('.')
+    """
+    v = version.split(".")
     ret = []
     for p in v:
         if p.isdigit():
@@ -27,4 +27,13 @@ def parse_version(version):
             ret.append(p)
     return tuple(ret)
 
+
 VERSION = parse_version(__version__)
+
+
+
+assert VERSION < (25,0), "Remove deprecated code"
+
+
+class RemovedInDjangoFilter25Warning(DeprecationWarning):
+    pass
